package dev.fitko.fitconnect.client.steps.sender;

import dev.fitko.fitconnect.api.domain.model.destination.Destination;
import dev.fitko.fitconnect.api.domain.model.event.EventLogEntry;
import dev.fitko.fitconnect.api.domain.model.event.EventStatus;
import dev.fitko.fitconnect.api.domain.model.submission.SentSubmission;
import dev.fitko.fitconnect.api.domain.model.submission.Submission;

import java.util.List;
import java.util.Optional;
import java.util.UUID;

public interface StartStep {

    /**
     * Creates new submission request.
     *
     * @return next step to add (optional) attachments
     */
    AttachmentsStep newSubmission();

    /**
     * Creates new submission request wit already encrypted data.
     *
     * @return next step to add (optional) attachments
     */
    EncryptedAttachmentsStep newSubmissionWithEncryptedData();

    /**
     * Retrieve the public encryption key
     *
     * @param destinationId unique identifier of a {@link Destination}
     * @return optional string containing the public JWK
     */
    Optional<String> getPublicKey(UUID destinationId);

    /**
     * Retrieve the entire event log for a submissions caseId of a specific destination.
     *
     * @param caseId unique identifier of the case the log should be retrieved for
     * @param destinationId unique identifier of the {@link Destination} the log should be retrieved for
     *
     * @return List of {@link EventLogEntry}s for the given case
     */
    List<EventLogEntry> getEventLog(UUID caseId, UUID destinationId);

    /**
     * Retrieve the current status of a {@link Submission}.
     *
     * @param sentSubmission the original {@link SentSubmission} the status should be retrieved for
     *
     * @return {@link EventStatus} the current status
     */
    EventStatus getStatusForSubmission(SentSubmission sentSubmission);
}
